==> open-xchange-guard_2.10.0.orig.tar.bz2: open-xchange-guard-2.10.0/com.openexchange.guard.secondfactor/src/com/openexchange/guard/secondfactor/SecondFactorService.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.secondfactor;

import com.openexchange.exception.OXException;

/**
 * {@link SecondFactorService}
 *
 * @author <a href="mailto:greg.hill@open-xchange.com">Greg Hill</a>
 * @since v2.10.0
 */
public interface SecondFactorService {

    /**
     * Check if the user has a second factor associated with the account
     * @param userid
     * @param cid
     * @return True if has a second factor
     * @throws OXException
     */
    public boolean hasSecondFactor (int userid, int cid) throws OXException;

    /**
     * Associated a second factor token with a user
     * @param userid
     * @param cid
     * @param token
     * @return true if successful
     * @throws OXException
     */
    public boolean addSecondFactor (int userid, int cid, String token) throws OXException;

    /**
     * Verify if the token matches/valid for the second factor
     * @param userid
     * @param cid
     * @param token
     * @throws OXException if not valid with details
     */
    public void verifySecondFactor (int userid, int cid, String token) throws OXException;

    /**
     * Remove the second factor token associated with the user
     * @param userid
     * @param cid
     * @throws OXException if fails for some reason
     */
    public void removeSecondFactor (int userid, int cid) throws OXException;

    /**
     * Remove the second factor token associated with the user if it is a single use token
     * @param userid
     * @param cid
     * @throws OXException if fails for some reason
     */
    public void removeSecondFactorIfSingleUse (int userid, int cid) throws OXException;

}

==> open-xchange-guard_2.10.5.orig.tar.bz2: open-xchange-guard-2.10.5/com.openexchange.guard.secondfactor/src/com/openexchange/guard/secondfactor/SecondFactorService.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.secondfactor;

import com.openexchange.exception.OXException;

/**
 * {@link SecondFactorService}
 *
 * @author <a href="mailto:greg.hill@open-xchange.com">Greg Hill</a>
 * @since v2.10.0
 */
public interface SecondFactorService {

    /**
     * Check if the user has a second factor associated with the account
     *
     * @param oxUserid
     * @param oxCid
     * @param guardUserId
     * @param guardContextId
     * @return True if has a second factor
     * @throws OXException
     */
    public boolean hasSecondFactor(int oxUserid, int oxCid, int guardUserId, int guardContextId) throws OXException;

    /**
     * Associated a second factor token with a user
     * 
     * @param oxUserid
     * @param oxCid
     * @param guardUserId
     * @param guardContextId
     * @param token
     * @return true if successful
     * @throws OXException
     */
    public boolean addSecondFactor(int oxUserid, int oxCid, int guardUserId, int guardContextId, String token) throws OXException;

    /**
     * Verify if the token matches/valid for the second factor
     *
     * @param oxUserid
     * @param oxCid
     * @param guardUserId
     * @param guardContextId
     * @param token
     * @throws OXException if not valid with details
     */
    public void verifySecondFactor(int oxUserid, int oxCid, int guardUserId, int guardContextId, String token) throws OXException;

    /**
     * Remove the second factor token associated with the user
     * @param userid
     * @param cid
     * @throws OXException if fails for some reason
     */
    public void removeSecondFactor (int userid, int cid) throws OXException;

    /**
     * Remove the second factor token associated with the user if it is a single use token
     * @param userid
     * @param cid
     * @throws OXException if fails for some reason
     */
    public void removeSecondFactorIfSingleUse (int userid, int cid) throws OXException;

}
